package com.idea.paymentManagement.service;

import cn.hutool.core.util.IdUtil;
import com.idea.customerManagement.mapper.ContractManageMapper;
import com.idea.customerManagement.model.ContractManage;
import com.idea.customerManagement.model.ContractManageExample;
import com.idea.paymentManagement.dto.RefundDetailDto;
import com.idea.paymentManagement.mapper.PayLogExtendMapper;
import com.idea.paymentManagement.mapper.PayLogMapper;
import com.idea.paymentManagement.mapper.RefundDetailMapper;
import com.idea.paymentManagement.model.*;
import com.rockstar.common.base.BaseService;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.system.service.SysDictService;
import com.rockstar.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Service
public class RefundDetailService implements BaseService<RefundDetail, RefundDetailExample> {

    @Autowired
    private RefundDetailMapper modelMapper;
    @Autowired
    private PayLogMapper payLogMapper;
    @Autowired
    private PayLogExtendMapper payLogExtendMapper;
    @Autowired
    private ContractManageMapper contractManageMapper;
    @Autowired
    private SysDictService sysDictService;


    @Override
    public int deleteByPrimaryKey(String s) {
        return modelMapper.deleteByPrimaryKey(s);
    }

    @Override
    public int insertSelective(RefundDetail refundDetail) {
        refundDetail.setId(IdUtil.simpleUUID());
        return modelMapper.insertSelective(refundDetail);
    }

    public int insertWithoutId(RefundDetail refundDetail) {
        return modelMapper.insertSelective(refundDetail);
    }

    @Override
    public RefundDetail selectByPrimaryKey(String s) {
        return modelMapper.selectByPrimaryKey(s);
    }

    @Override
    public int updateByPrimaryKeySelective(RefundDetail refundDetail) {
        return modelMapper.updateByPrimaryKeySelective(refundDetail);
    }

    @Override
    public int updateByExampleSelective(RefundDetail refundDetail, RefundDetailExample refundDetailExample) {
        return modelMapper.updateByExampleSelective(refundDetail, refundDetailExample);
    }

    @Override
    public int updateByExample(RefundDetail refundDetail, RefundDetailExample refundDetailExample) {
        return modelMapper.updateByExample(refundDetail, refundDetailExample);
    }

    @Override
    public List<RefundDetail> selectByExample(RefundDetailExample refundDetailExample) {
        return modelMapper.selectByExample(refundDetailExample);
    }

    @Override
    public long countByExample(RefundDetailExample refundDetailExample) {
        return modelMapper.countByExample(refundDetailExample);
    }

    @Override
    public int deleteByExample(RefundDetailExample refundDetailExample) {
        return modelMapper.deleteByExample(refundDetailExample);
    }


    /**
     * 根据轮号客户id 查询已收 部分收款 完全收款
     *
     * @param customerManagementId
     * @return
     */
    public List<RefundDetailDto> getByCustomerManagementId(String customerManagementId, String houseId) {

        List<RefundDetailDto> refundDetails = new ArrayList<>();
        ContractManageExample example = new ContractManageExample();
        example.createCriteria().andCustomerManagementIdEqualTo(customerManagementId).andHouseIdEqualTo(houseId);
        List<ContractManage> contractManages = contractManageMapper.selectByExample(example);
        ContractManage contractManage = contractManages.get(0);

        List<Map<String, String>> dictList = sysDictService.selectDictList("CONTENT_TYPE");
        List<PayLog> contentTypeMoney = payLogExtendMapper.getContentTypeMoneyByContractId(contractManage.getId(), 1);
        for (PayLog payLog : contentTypeMoney) {
            String type = "";
            for (Map<String, String> map : dictList){
                if(map.get("value").equals(payLog.getContentType().toString())){
                    type = map.get("label");
                }
            }
            RefundDetailDto refundDetail = new RefundDetailDto();
            refundDetail.setType(type);
            refundDetail.setContentType(payLog.getContentType());
            refundDetail.setReceivedAmount(payLog.getPayMoney());
            refundDetail.setUuid(IdUtil.simpleUUID());
            refundDetails.add(refundDetail);
        }


        // 专项维修资金
        String funds = payLogExtendMapper.getMoneyByContractId(contractManage.getId(), 2);
        RefundDetailDto refundDetail2 = new RefundDetailDto();
        refundDetail2.setType("专项维修资金");
        refundDetail2.setContentType(4);
        refundDetail2.setReceivedAmount(new BigDecimal(funds));
        refundDetail2.setUuid(IdUtil.simpleUUID());
        refundDetails.add(refundDetail2);

        return refundDetails;
    }

    public List<RefundDetail> listAll(RefundDetail model, DateTrans dt) {
        return modelMapper.selectByExample(getCondition(model, dt));
    }


    private RefundDetailExample getCondition(RefundDetail model, DateTrans dt) {
        RefundDetailExample ex = new RefundDetailExample();
        ex.setOrderByClause("created_at");
        RefundDetailExample.Criteria criteria = ex.createCriteria();
        if (StringUtils.isNotEmpty(model.getRefundManageId())) {
            criteria.andRefundManageIdEqualTo(model.getRefundManageId());
        }
        return ex;
    }

}
