package com.idea.pro.wx.controller.customerManagement;

import com.github.pagehelper.PageInfo;
import com.idea.customerManagement.dto.IntentionalDepositDto;
import com.idea.customerManagement.model.IntentionalDeposit;
import com.idea.customerManagement.service.IntentionalDepositService;
import com.rockstar.common.base.BaseController;
import com.rockstar.common.domain.AjaxResult;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.TableSplitResult;
import com.rockstar.frame.model.extend.Tablepar;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletResponse;

@Controller
@RequestMapping(value = "/wx/IntentionalDepositController")
@Api(tags = "意向金管理")
public class WxIntentionalDepositController extends BaseController {

    @Autowired
    private IntentionalDepositService modelService;


    /**
     * 获取意向金流水号
     *
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "getSerialNumber", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public String getSerialNumber(String customerManagementId) {
        return modelService.getSerialNumber(customerManagementId);
    }


    /**
     * 获取定金金流水号
     *
     * @param id
     * @return
     */
    @PostMapping(value = "getDepositSerialNumber", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public String getDepositSerialNumber(String id) {
        return modelService.getDepositSerialNumber(id);
    }


    /**
     * 意向金登记
     *
     * @param model
     * @return
     */
    @PostMapping(value = "add", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult add(IntentionalDeposit model, String userId) {
        int result = modelService.add(model, userId);
        return result(result);
    }

    /**
     * 意向金修改
     *
     * @param model
     * @return
     */
    @PostMapping(value = "edit", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult edit(IntentionalDeposit model, String userId) {
        int result = modelService.edit(model, userId);
        return result(result);
    }

    /**
     * 根据客户id查找意向金
     *
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "getByCustomerManagementId", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object getByCustomerManagementId(String customerManagementId) {
        return modelService.getByCustomerManagementId(customerManagementId);
    }


    @PostMapping(value = "list", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object list(Tablepar tablepar, IntentionalDepositDto model, DateTrans dt) {
        PageInfo<IntentionalDepositDto> page = modelService.listByModel(tablepar, model, dt);
        TableSplitResult<IntentionalDepositDto> result = new TableSplitResult<IntentionalDepositDto>(page.getPageNum(), page.getTotal(), page.getList());
        return result;
    }

    /**
     * 意向金转定金
     *
     * @param model
     * @return
     */
    @PostMapping(value = "toDeposit", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult toDeposit(IntentionalDeposit model,String userId) {
        int result = modelService.toDeposit(model,userId);
        return result(result);
    }

    /**
     * 退意向金
     *
     * @param model
     * @return
     */
    @PostMapping(value = "refund", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult refund(IntentionalDeposit model) {
        int result = modelService.refund(model);
        return result(result);
    }

    /**
     * 根据客户id查找意向金
     *
     * @param id
     * @return
     */
    @PostMapping(value = "getById", produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object getById(String id) {
        return modelService.getById(id);
    }


    /**
     * 意向金收据下载
     *
     * @param model
     * @param response
     */
    @GetMapping(value = "downLoadReceipt", produces = {"application/json;charset=UTF-8"})
    public void downLoadReceipt(IntentionalDeposit model, HttpServletResponse response) {
        modelService.downLoadReceipt(model, response);
    }


}
